@@ -60,6 +60,7 @@ class GLTF(object):
         self.skins = []
         self.animations = []
         self.extensions_used = []
+        self.extras = {}
         self.folder = folder
         self.filename = filename
         self.asset = {
@@ -198,6 +199,10 @@ class GLTF(object):
         if extensions:
             gltf.extensions_used = extensions
 
+        extras = data.get('extras')
+        if extras:
+            gltf.extras = extras
+
         for buf in data.get('buffers', []):
             gltf.buffers.append(Buffer(buf, gltf))
 
@@ -337,6 +342,9 @@ class GLTF(object):
         if self.extensions_used:
             data['extensionsUsed'] = self.extensions_used
 
+        if self.extras:
+            data['extras'] = self.extras
+
         if self.materials:
             data['materials'] = [mat.render(self) for mat in self.materials]
 
