@@ -400,6 +400,8 @@ class Node(BaseGLTFStructure):
     matrix = None
     skin = None
     camera = None
+    extensions = None
+    extras = None
 
     def __init__(self, node=None, gltf=None, name=None, mesh=None, children=None,
                  skin=None, camera=None):
@@ -413,6 +415,12 @@ class Node(BaseGLTFStructure):
             if 'camera' in node:
                 self.camera = gltf.cameras[node['camera']]
 
+            if 'extensions' in node:
+                self.extensions = node['extensions']
+
+            if 'extras' in node:
+                self.extras = node['extras']
+
             translation = node.get('translation')
             if translation:
                 self.translation = np.array(translation, dtype='float32')
@@ -549,4 +557,8 @@ class Node(BaseGLTFStructure):
             node['scale'] = self.scale.tolist()
         if self.matrix is not None:
             node['matrix'] = self.matrix.reshape((16,)).tolist()
+        if self.extensions:
+            node['extensions'] = self.extensions
+        if self.extras:
+            node['extras'] = self.extras
         return node
