@@ -15,6 +15,7 @@ model.save("output.glb")
 """
 import copy
 import logging
+import math
 
 import numpy as np
 from PIL import Image as PImage
@@ -319,7 +320,7 @@ def analyze(model):
         mesh_triangle_count = 0
         for p in m.primitives:
             vertex_count += p.positions.count
-            if p.mode is None or p.mode == 4:
+            if p.mode is None or p.mode.value == 4:
                 mesh_triangle_count += int((p.indices.count if p.indices else p.positions.count) / 3)
             else:
                 print(f'Unsupported primitive mode: {p.mode}')
@@ -343,11 +344,45 @@ def analyze(model):
     mesh_count = len(model.meshes)
     mat_count = len(model.materials)
 
+    texture_set = set()
+    max_texture_size = (0, 0)
+
+    def add_texture(tex):
+        if tex not in texture_set:
+            texture_set.add(tex)
+            im_size = tex.source.get_pil_image().size
+            if max_texture_size[0] * max_texture_size[1] < im_size[0] * im_size[1]:
+                return im_size
+            return max_texture_size
+
+    pbr_texture_set = set()
+    for mat in model.materials:
+        if mat.color_texture:
+            max_texture_size = add_texture(mat.color_texture)
+        if mat.normal_texture:
+            max_texture_size = add_texture(mat.normal_texture)
+        if mat.emissive_texture:
+            max_texture_size = add_texture(mat.emissive_texture)
+        if mat.occlusion_texture:
+            max_texture_size = add_texture(mat.occlusion_texture)
+        if mat.rough_metal_texture:
+            max_texture_size = add_texture(mat.rough_metal_texture)
+            pbr_texture_set.add(mat.rough_metal_texture)
+        if mat.spec_gloss_texture:
+            max_texture_size = add_texture(mat.spec_gloss_texture)
+            pbr_texture_set.add(mat.spec_gloss_texture)
+    texture_count = len(texture_set)
+    pbr_texture_count = len(pbr_texture_set)
+
     # Get the animation channel count for unique TRS segments. ARCore has a hard limit of 254 of these.
     targets = set()
+    animation_count = len(model.animations)
+    max_animation_duration = 0
     for a in model.animations:
         for c in a.channels:
             targets.add(id(c.target_node))
+        for s in a.samplers:
+            max_animation_duration = max(max_animation_duration, math.ceil(s.input.max[0]))
     animation_target_count = len(targets)
 
     # Get sampler count
@@ -355,28 +390,94 @@ def analyze(model):
 
     return {
         'features': {
-            'header': ("Feature", "Count", "Recommended", "✓"),
-            'rows': [
-                (label, count, recommended, count < recommended)
-                for label, count, recommended in
-                [
-                    ("Mesh Vertices", vertex_count, 30_000),
-                    ("Instanced Vertices", instanced_vertex_count, 30_000),
-                    ("Triangle Count", triangle_count, 100_000),
-                    ("Rendered Triangle Count", rendered_triangle_count, 100_000),
-                    ("Meshes", mesh_count, 10),
-                    ("Materials", mat_count, 10),
-                    ("Animation Targets", animation_target_count, 254),
-                    ("Animation Samplers", sampler_count, 9999),
-                ]
-            ]
+            'mesh_vertices': {
+                'name': "Mesh Vertices",
+                'count': vertex_count,
+                'recommended': 30_000,
+                'within_limit': vertex_count <= 30_000
+            },
+            'instanced_vertices': {
+                'name': "Instanced Vertices",
+                'count': instanced_vertex_count,
+                'recommended': 30_000,
+                'within_limit': instanced_vertex_count <= 30_000
+            },
+            'triangles': {
+                'name': "Triangles",
+                'count': triangle_count,
+                'recommended': 100_000,
+                'within_limit': triangle_count <= 100_000
+            },
+            'rendered_triangles': {
+                'name': "Rendered Triangles",
+                'count': rendered_triangle_count,
+                'recommended': 100_000,
+                'within_limit': rendered_triangle_count <= 100_000
+            },
+            'meshes': {
+                'name': "Meshes",
+                'count': mesh_count,
+                'recommended': 10,
+                'within_limit': mesh_count <= 10
+            },
+            'materials': {
+                'name': "Materials",
+                'count': mat_count,
+                'recommended': 10,
+                'within_limit': mat_count <= 10
+            },
+            'textures': {
+                'name': 'All Textures',
+                'count': texture_count,
+                'recommended': 10,
+                'within_limit': texture_count <= 10,
+            },
+            'pbr_textures': {
+                'name': 'PBR Textures',
+                'count': pbr_texture_count,
+                'recommended': 2,
+                'within_limit': pbr_texture_count <= 2
+            },
+            'texture_x_dimension': {
+                'name': 'Max Texture X Dimension',
+                'count': max_texture_size[0],
+                'recommended': 2048,
+                'within_limit': max_texture_size[0] <= 2048
+            },
+            'texture_y_dimension': {
+                'name': 'Max Texture Y Dimension',
+                'count': max_texture_size[1],
+                'recommended': 2048,
+                'within_limit': max_texture_size[1] <= 2048
+            },
+            'animations': {
+                'name': 'Animations',
+                'count': animation_count,
+                'recommended': 1,
+                'within_limit': animation_count <= 1
+            },
+            'animation_duration': {
+                'name': 'Max Animation Duration',
+                'count': max_animation_duration,
+                'recommended': 10,
+                'within_limit': max_animation_duration <= 10
+            },
+            'animation_targets': {
+                'name': "Animation Targets",
+                'count': animation_target_count,
+                'recommended': 254,
+                'within_limit': animation_target_count <= 254
+            },
+            'animation_samplers': {
+                'name': "Animation Samplers",
+                'count': sampler_count,
+                'recommended': 9999,
+                'within_limit': sampler_count <= 9999
+            },
         },
         'sizes': {
-            'header': ("Data Type", "Size"),
-            'rows': [
-                (k, _format_bytes(val))
-                for k, val in sizes.items()
-            ]
+            k: _format_bytes(v)
+            for k, v in sizes.items()
         }
     }
 
@@ -386,6 +487,20 @@ def print_analysis(model):
     Prints a filesize analysis of the GLTF file.
     """
     analysis = analyze(model)
+    analysis['features'] = {
+        'header': ('Feature', 'Count', 'Recommended', '✓'),
+        'rows': [
+            (v['name'], v['count'], v['recommended'], v['within_limit'])
+            for v in analysis['features'].values()
+        ]
+    }
+    analysis['sizes'] = {
+        'header': ('Data Type', 'Size'),
+        'rows': [
+            (k, v)
+            for k, v in analysis['sizes'].items()
+        ]
+    }
 
     def printheader(*args):
         headerstr = " {:>24} | " + ("{:>12} | " * (len(args) - 2)) + "{}"
